/* sd-card-helper: sd card helper daemon to access sd card storage
 * Copyright (C) 2018 Robert Bosch Power Tools GmbH
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Author: Vinay Kumar Shettar <vinaykumar.shettar@in.bosch.com>
 */
/**
 * @file sd-card-helper.h
 * @brief header file of sd-card-helper.
 *
 * @copydoc sd-card-helper
 */

#ifndef SD_CARD_HELPER_H
#define SD_CARD_HELPER_H
#pragma once

#include <sd-card-helper-generated.h>

/**
 * @brief sd-card-helper function declarations.
 * Detailed description.
 * Concept Based on GDBus IPC (Property, Methods, Signal)
 * For Reference
 * https://developer.gnome.org/gio/stable/gdbus-convenience.html
 * For Example
 * https://developer.gnome.org/gio/stable/gdbus-codegen.html
 */
typedef enum {
        SDCARD_FORMAT_STATE_UNKNOWN = 0,
        SDCARD_FORMAT_STARTED,
        SDCARD_FORMAT_DONE = 100,
        SDCARD_FORMAT_FAILED = 200
} SdCardHelperFormatStatus;

typedef struct
{
  /* D-Bus server object for setting the status and result values */
  ComBosch_ptSdCardHelper *sd_card_helper_object;
  GMainLoop *main_loop;
  GVolumeMonitor *volume;
  gchar *mount_path;
  struct udev *udev;
  struct udev_monitor *udev_monitor;
  guint io_watch_udev;
  GIOChannel *udev_io_channel;
} SDCardHelper;

void sd_card_helper_bus_acquired (GDBusConnection *connection,
                                  const gchar *name, gpointer user_data);
void sd_card_helper_name_acquired (GDBusConnection *connection,
                                   const gchar *name, gpointer user_data);
void sd_card_helper_name_lost (GDBusConnection *connection, const gchar *name,
                               gpointer user_data);
void sd_card_helper_init (SDCardHelper *sd_card_helper);
void sd_card_helper_deinit (SDCardHelper *sd_card_helper);

#endif /* SD_CARD_HELPER_H */
