/* sd-card-helper: sd card helper daemon to access sd card storage
 * Copyright (C) 2007-2011 David Zeuthen <zeuthen@gmail.com>
 * Copyright (C) 2018 Robert Bosch Power Tools GmbH
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include "sd-card-helper-logging.h"
#include <sys/syscall.h>
#include <sys/types.h>

/**
 * SECTION:sd-card-helper-logging
 * @title: Logging
 * @short_description: Logging Routines
 *
 * Logging routines.
 */

/**
 * sd_card_helper_log:
 * @level: A #UsbmsgdLogLevel.
 * @function: Pass #G_STRFUNC here.
 * @location: Pass #G_STRLOC here.
 * @format: printf()-style format.
 * @...: Arguments for format.
 *
 * Low-level logging function used by sd_card_helper_debug() and other macros.
 */
void
sd_card_helper_log (SdCardHelperLogLevel level, const gchar *function,
                    const gchar *location, const gchar *format, ...)
{
  va_list var_args;
  gchar *message;

  va_start (var_args, format);
  message = g_strdup_vprintf (format, var_args);
  va_end (var_args);

#if GLIB_CHECK_VERSION(2, 50, 0)
  g_log_structured ("sd-card-helper", (GLogLevelFlags)level, "MESSAGE", "%s",
                    message, "THREAD_ID", "%d", (gint)syscall (SYS_gettid),
                    "CODE_FUNC", function, "CODE_FILE", location);
#else
  g_log ("sd-card-helper", level, "[%d]: %s [%s, %s()]",
         (gint)syscall (SYS_gettid), message, location, function);
#endif

  g_free (message);
}
